import sys
import os


def redirect(stdout=None, stderr=None):
    for dev, v in [(stdout, 'stdout'), (stderr, 'stderr')]:
        s = dev or os.getenv(v.upper())
        if s:
            setattr(sys, v, open(s, 'w'))



__version__ = '0.0.115'

import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='pyaltt2',
    version=__version__,
    author='Altertech',
    author_email='div@altertech.com',
    description='Misc tools',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/alttch/pyaltt2',
    include_package_data=True,
    packages=setuptools.find_packages(),
    license='MIT',
    install_requires=[],
    classifiers=(
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Topic :: Software Development :: Libraries',
    ),
)
